---
title: File Formats
hide:
- navigation
---




<!-- 

- JSON
- TOML
- YAML
- JSONL
- JSONC
- XML
- ZST
- CSV
- XLS
- XLSX
- XLSB
- JPEG
- PNG

## Base Module Complete

- [ ] JSON


## Meta Module Complete -->